@@ -57,9 +57,10 @@ def gen_site_map_item(cls):
 	}
 
 def _render_sitemap(segments, output_path, SITE_URL) -> None:
-	map_items = [gen_site_map_item(x) for x in segments]
+	map_items = set([gen_site_map_item(x) for x in segments])
 	_segments = list(chunked(map_items, 500000))
 	
+	
 	for i, segment in enumerate(_segments):
 		_map = SiteMapEngine().get_template('sitemap.xml')
 		sitemap_content = _map.render(SITE_URL=SITE_URL, items = segment)
